@@ -5,7 +5,7 @@ import tornado.web
 from wpull.backport.testing import unittest
 from wpull.errors import ConnectionRefused, SSLVerficationError
 from wpull.http import (Request, Connection, NetworkError, ProtocolError, Client,
-    ConnectionPool)
+    ConnectionPool, parse_charset)
 from wpull.testing.badapp import BadAppTestCase
 
 
@@ -153,7 +153,11 @@ class TestConnection(BadAppTestCase):
         except NetworkError:
             pass
         else:
-            self.assertFalse(True)
+            self.fail()
+
+    @tornado.testing.gen_test(timeout=DEFAULT_TIMEOUT)
+    def test_unclean_8bit_header(self):
+        yield self.fetch('/unclean_8bit_header')
 
 
 class TestClient(BadAppTestCase):
@@ -233,6 +237,32 @@ class TestHTTP(unittest.TestCase):
             request.header()
         )
 
+    def test_parse_charset(self):
+        self.assertEqual(
+            None,
+            parse_charset('text/plain')
+        )
+        self.assertEqual(
+            None,
+            parse_charset('text/plain; charset=')
+        )
+        self.assertEqual(
+            'utf_8',
+            parse_charset('text/plain; charset=utf_8')
+        )
+        self.assertEqual(
+            'UTF-8',
+            parse_charset('text/plain; charset="UTF-8"')
+        )
+        self.assertEqual(
+            'Utf8',
+            parse_charset("text/plain; charset='Utf8'")
+        )
+        self.assertEqual(
+            'UTF-8',
+            parse_charset('text/plain; CHARSET="UTF-8"')
+        )
+
 
 class TestSSL(tornado.testing.AsyncHTTPSTestCase):
     def get_app(self):
